@@ -112,6 +112,10 @@ if (parsedArgs.settings) {
         // Consider compatibility for older versions
         settingsFile = path.join(process.env.HOMEPATH,".node-red","settings.js");
     } else {
+        if (!parsedArgs.userDir && !(process.env.HOME || process.env.USERPROFILE || process.env.HOMEPATH)) {
+            console.log("Could not find user directory. Ensure $HOME is set for the current user, or use --userDir option")
+            process.exit(1)
+        }
         var userDir = parsedArgs.userDir || path.join(process.env.HOME || process.env.USERPROFILE || process.env.HOMEPATH,".node-red");
         var userSettingsFile = path.join(userDir,"settings.js");
         if (fs.existsSync(userSettingsFile)) {
@@ -298,6 +302,26 @@ httpsPromise.then(function(startupHttps) {
         settings.httpNodeAuth = settings.httpNodeAuth || settings.httpAuth;
     }
 
+    if(settings.httpStatic) {
+        settings.httpStaticRoot = formatRoot(settings.httpStaticRoot || "/");
+        const statics = Array.isArray(settings.httpStatic) ? settings.httpStatic : [settings.httpStatic];
+        const sanitised = [];
+        for (let si = 0; si < statics.length; si++) {
+            let sp = statics[si];
+            if(typeof sp === "string") {
+                sp = { path: sp, root: "" }
+                sanitised.push(sp);
+            } else if (typeof sp === "object" && sp.path ) {
+                sanitised.push(sp);
+            } else {
+                continue;
+            }
+            sp.subRoot = formatRoot(sp.root);
+            sp.root = formatRoot(path.posix.join(settings.httpStaticRoot,sp.subRoot));
+        }
+        settings.httpStatic = sanitised.length ? sanitised : false;    
+    }
+
     // if we got a port from command line, use it (even if 0)
     // replicate (settings.uiPort = parsedArgs.port||settings.uiPort||1880;) but allow zero
     if (parsedArgs.port !== undefined){
@@ -390,12 +414,28 @@ httpsPromise.then(function(startupHttps) {
     if (settings.httpNodeRoot !== false) {
         app.use(settings.httpNodeRoot,RED.httpNode);
     }
+    // if (settings.httpStatic) {
+    //     settings.httpStaticAuth = settings.httpStaticAuth || settings.httpAuth;
+    //     if (settings.httpStaticAuth) {
+    //         app.use("/",basicAuthMiddleware(settings.httpStaticAuth.user,settings.httpStaticAuth.pass));
+    //     }
+    //     app.use("/",express.static(settings.httpStatic));
+    // }
     if (settings.httpStatic) {
-        settings.httpStaticAuth = settings.httpStaticAuth || settings.httpAuth;
-        if (settings.httpStaticAuth) {
-            app.use("/",basicAuthMiddleware(settings.httpStaticAuth.user,settings.httpStaticAuth.pass));
+        let appUseMem = {};
+        for (let si = 0; si < settings.httpStatic.length; si++) {
+            const sp = settings.httpStatic[si];
+            const filePath = sp.path;
+            const thisRoot = sp.root || "/";
+            if(appUseMem[filePath + "::" + thisRoot]) {
+                continue;// this path and root already registered!
+            }
+            appUseMem[filePath + "::" + thisRoot] = true;
+            if (settings.httpStaticAuth) {
+                app.use(thisRoot, basicAuthMiddleware(settings.httpStaticAuth.user, settings.httpStaticAuth.pass));
+            }
+            app.use(thisRoot, express.static(filePath));
         }
-        app.use("/",express.static(settings.httpStatic));
     }
 
     function getListenPath() {
